@@ -18,10 +18,6 @@ import (
 const (
 	homeDir        = "/home/someone"
 	homeDirWindows = "C:\\Users\\someone"
-	fooBarMan      = "\\foo\\bar\\man"
-	abc            = "/abc"
-	abcd           = "/a/b/c/d"
-	cdefg          = "/c/d/e/f/g"
 )
 
 func renderTemplateNoTrimSpace(env *mock.Environment, segmentTemplate string, context any) string {
@@ -358,7 +354,9 @@ func TestGetFolderSeparator(t *testing.T) {
 		env.On("Shell").Return(shell.GENERIC)
 
 		template.Cache = &cache.Template{
-			Shell: "bash",
+			SimpleTemplate: cache.SimpleTemplate{
+				Shell: "bash",
+			},
 		}
 		template.Init(env, nil, nil)
 
@@ -643,7 +641,7 @@ func TestAgnosterMaxWidth(t *testing.T) {
 			env.On("Shell").Return(shell.BASH)
 
 			path := &Path{
-				base: base{
+				Base: Base{
 					env: env,
 					props: properties.Map{
 						DisplayRoot:         tc.displayRoot,
@@ -804,7 +802,7 @@ func TestFishPath(t *testing.T) {
 			env.On("Shell").Return(shell.BASH)
 
 			path := &Path{
-				base: base{
+				Base: Base{
 					env: env,
 					props: properties.Map{
 						DirLength:      tc.dirLength,
