@@ -28,14 +28,12 @@ func (s *PlasticStatus) add(code string) {
 }
 
 type Plastic struct {
-	scm
-
-	Status       *PlasticStatus
+	Status                 *PlasticStatus
+	Selector               string
+	plasticWorkspaceFolder string
+	Scm
 	Behind       bool
-	Selector     string
 	MergePending bool
-
-	plasticWorkspaceFolder string // root folder of workspace
 }
 
 func (p *Plastic) Init(props properties.Properties, env runtime.Environment) {
@@ -57,10 +55,6 @@ func (p *Plastic) Enabled() bool {
 		return false
 	}
 
-	if p.shouldIgnoreRootRepository(wkdir.ParentFolder) {
-		return false
-	}
-
 	if !wkdir.IsDir {
 		return false
 	}
@@ -74,6 +68,15 @@ func (p *Plastic) Enabled() bool {
 	return true
 }
 
+func (p *Plastic) CacheKey() (string, bool) {
+	dir, err := p.env.HasParentFilePath(".plastic", true)
+	if err != nil {
+		return "", false
+	}
+
+	return dir.Path, true
+}
+
 func (p *Plastic) setPlasticStatus() {
 	output := p.getCmCommandOutput("status", "--all", "--machinereadable")
 	splittedOutput := strings.Split(output, "\n")
@@ -139,7 +142,7 @@ func (p *Plastic) getHeadChangeset() int {
 
 func (p *Plastic) setSelector() {
 	var ref string
-	selector := p.FileContents(p.plasticWorkspaceFolder+"/.plastic/", "plastic.selector")
+	selector := p.fileContent(p.plasticWorkspaceFolder+"/.plastic/", "plastic.selector")
 
 	// changeset
 	ref = p.parseChangesetSelector(selector)
